# RSA Electie library
Adapted RSA library for university project called Electie.

Library is uploaded to PyPI on this [link](https://pypi.org/search/?q=rsaelectie).

## How to install library
`pip install rsaelectie`

## How to use library in project
`import rsaelectie` or `from rsaelectie import rsaelectie`